import { AfterViewInit, EventEmitter, OnDestroy, OnInit, TemplateRef } from '@angular/core';
import { ControlValueAccessor } from '@angular/forms';
import { BehaviorSubject } from 'rxjs';
import { Cursor } from './cursor';
import { ToolbarIcons } from './toolbar-icons';
import * as i0 from "@angular/core";
export declare class EditormdComponent implements ControlValueAccessor, OnDestroy, OnInit, AfterViewInit {
    /**
     * 发生用户输入事件时触发
     *
     */
    input: EventEmitter<string>;
    toolbarIconSaveClicked: EventEmitter<EditormdComponent>;
    /**
     * Markdown预览内容渲染完成事件
     * @type {EventEmitter<EditormdComponent>}
     */
    previewContentReady: EventEmitter<EditormdComponent>;
    loaded: EventEmitter<EditormdComponent>;
    /**
     * default value is: `editor.md/`
     *
     */
    libPath: string;
    /**
     * default to `true`
     */
    lineNumbers: boolean;
    /**
     * default:
     * ```js
     * {
     *   src: `${this.libPath}lib/jquery.min.js`,
     *   tagId: 'jquery-script',
     * }
     * ```
     *
     */
    jqueryOption: {
        src: string;
        tagId: string;
    };
    toolbarIcons: ToolbarIcons[] | 'mini' | 'simple' | 'full' | 'cnblogsSimple';
    appendToolbarIcons: ToolbarIcons[];
    saveIconText: string;
    editormdVersionSuffix: string;
    /**
     * 是否正在初始化
     *
     */
    initializing$: BehaviorSubject<boolean>;
    private _disabled;
    get disabled(): boolean;
    set disabled(value: boolean);
    private _highlightCodeOption;
    get highlightCodeOption(): {
        enable: boolean;
        highlightCode?: (iframe: HTMLIFrameElement) => void;
    };
    /**
     * 设置实时预览时代码高亮配置
     *
     * `enable`: default is `false`
     *
     *  `highlightCode`: default:
     *  ```js
     *  loadScript(
     *     'prettify-js',
     *     `${this.libPath}lib/prettify.min.js`
     *   ).then(() => {
     *     this._editor.previewCodeHighlight();
     *   });
     *  ```
     */
    set highlightCodeOption(value: {
        enable: boolean;
        highlightCode?: (iframe: HTMLIFrameElement) => void;
    });
    private _mathjaxSrc;
    /**
     * default value is: `https://cdn.jsdelivr.net/npm/mathjax@2/MathJax.js?config=TeX-AMS-MML_CHTML`
     *
     */
    get mathjaxSrc(): string;
    set mathjaxSrc(src: string);
    private _uploadImage;
    /**
     * 图片上传方法, 粘贴图片时会使用这个方法上传图片
     *
     */
    set uploadImage(value: (imageFile: any) => Promise<string>);
    get uploadImage(): (imageFile: any) => Promise<string>;
    private _enableSearchReplace;
    set enableSearchReplace(v: boolean);
    id: number;
    get enableSearchReplace(): boolean;
    private _markdownToHtml;
    get markdownToHtml(): (markdown: string) => Promise<string> | string;
    /**
     * markdown转换为html方法, 实时预览时会使用这个方法渲染markdown
     *
     */
    set markdownToHtml(value: (markdown: string) => Promise<string> | string);
    private _loadingTemplate?;
    /**
     * 加载中占位符
     *
     */
    get loadingTemplate(): TemplateRef<any>;
    set loadingTemplate(value: TemplateRef<any>);
    private _height;
    get height(): string;
    /**
     * 设置编辑器高度
     *
     */
    set height(value: string);
    private _width;
    get width(): string;
    /**
     * 设置编辑器宽度
     *
     */
    set width(value: string);
    private _enableMathjax;
    get enableMathjax(): boolean;
    /**
     * 设置是否开启数学公式支持
     *
     * @type {boolean}
     */
    set enableMathjax(value: boolean);
    private _zIndex;
    get zIndex(): number;
    /**
     * z轴顺序, 默认为1000
     * z轴顺序, 默认为1000
     *
     */
    set zIndex(value: number);
    get realtimePreview(): boolean;
    /**
     * 设置是否开启实时预览
     *
     */
    set realtimePreview(value: boolean);
    private _placeholder;
    set placeholder(value: string);
    get placeholder(): string;
    private get editorState();
    get previewContainerEl(): HTMLDivElement;
    get previewFrame(): HTMLIFrameElement;
    get previewWindow(): Window;
    get previewDocument(): Document;
    private get markdownTextarea();
    private _editor;
    private _realTimePreviewCache?;
    private $cmContentChanged;
    private _sub;
    private onChange;
    private onTouch;
    constructor();
    get markdown(): any;
    /**
     * 编辑器当前内容的总行数
     */
    get lineCount(): number;
    /**
     * 关闭实时预览
     *
     */
    closeRealtimePreview(): void;
    /**
     * 打开实时预览
     *
     */
    openRealtimePreview(): void;
    /**
     * 设置编辑器焦点
     *
     * @param {boolean} [moveCursorToEnd=false] 是否将光标移动到最后
     */
    focusEditor(moveCursorToEnd?: boolean): void;
    /**
     * 在当前光标位置插入文本值
     *
     * @param {string} value
     */
    insertValue(value: string): void;
    /**
     * 替换 from 和 to 直接的内容为 replacement
     *
     * @param {string} replacement
     * @param {Cursor} from
     * @param {Cursor} to
     * @param {string} origin
     */
    replaceRange(replacement: string, from: Cursor, to: Cursor, origin?: string): void;
    /**
     * 退出全屏
     *
     */
    exitFullScreen(): void;
    /**
     * 进入全屏编辑模式
     *
     */
    enterFullScreen(): void;
    ngOnInit(): void;
    ngAfterViewInit(): Promise<void>;
    ngOnDestroy(): void;
    writeValue(value: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    setDisabledState(isDisabled: boolean): void;
    onFocus(): void;
    /**
     * 剪贴板事件处理程序
     */
    onPaste(event: ClipboardEvent): Promise<void>;
    onDrop(e: DragEvent): void;
    allowDrop(ev: DragEvent): void;
    syncPreviewScroll(): void;
    /**
     * 上传剪贴板中的图片文件
     *
     * @private
     * @param event
     */
    private uploadImageFromClipboard;
    private uploadImageFromFile;
    private uploadImageAndInsertImageLinkToEditor;
    /**
     * 初始化编辑器
     * 1. 动态加载资源外部(包括css和js)
     * 2. 初始化编辑器设置, 并对相关事件进行监听
     *
     * @private
     */
    private initEditormd;
    private buildToolbarIcons;
    private onEditormdLoaded;
    private initKeyMaps;
    /**
     * 加载并配置mathjax
     */
    private loadMathjax;
    /**
     * 确保在editormd初始化完成后执行指定的操作
     *
     * @private
     * @param {(editor: any) => void} action
     */
    private execEnsureEditormdLoaded;
    /**
     * 加载jquery
     */
    private loadJquery;
    /**
     * 加载editormd.min.js
     *
     * @private
     */
    private loadEditormd;
    /**
     * 加载editormd.css
     *
     * @private
     */
    private loadEditormdCss;
    /**
     * 发生输入事件时的处理程序
     *
     * @private
     */
    private onTyped;
    private resize;
    /**
     * Docs from CodeMirror official web site:
     * If your code does something to change the size of the editor element (window resizes are
     * already listened for), or unhides it, you should probably follow up by calling this method to ensure CodeMirror is still
     * looking as intended.
     *
     * @private
     */
    private refreshCodeMirror;
    /**
     * override editormd.save()
     */
    private save;
    private openSearchDialog;
    private insertCollapsibleCodeBlock;
    private loadPreviewStyle;
    private onWindowResize;
    static ɵfac: i0.ɵɵFactoryDeclaration<EditormdComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<EditormdComponent, "emd-markdown-editor", never, { "libPath": { "alias": "libPath"; "required": false; }; "lineNumbers": { "alias": "lineNumbers"; "required": false; }; "jqueryOption": { "alias": "jqueryOption"; "required": false; }; "toolbarIcons": { "alias": "toolbarIcons"; "required": false; }; "appendToolbarIcons": { "alias": "appendToolbarIcons"; "required": false; }; "saveIconText": { "alias": "saveIconText"; "required": false; }; "editormdVersionSuffix": { "alias": "editormdVersionSuffix"; "required": false; }; "disabled": { "alias": "disabled"; "required": false; }; "highlightCodeOption": { "alias": "highlightCodeOption"; "required": false; }; "mathjaxSrc": { "alias": "mathjaxSrc"; "required": false; }; "uploadImage": { "alias": "uploadImage"; "required": false; }; "enableSearchReplace": { "alias": "enableSearchReplace"; "required": false; }; "markdownToHtml": { "alias": "markdownToHtml"; "required": false; }; "loadingTemplate": { "alias": "loadingTemplate"; "required": false; }; "height": { "alias": "height"; "required": false; }; "width": { "alias": "width"; "required": false; }; "enableMathjax": { "alias": "enableMathjax"; "required": false; }; "zIndex": { "alias": "zIndex"; "required": false; }; "realtimePreview": { "alias": "realtimePreview"; "required": false; }; "placeholder": { "alias": "placeholder"; "required": false; }; }, { "input": "input"; "toolbarIconSaveClicked": "toolbarIconSaveClicked"; "previewContentReady": "previewContentReady"; "loaded": "loaded"; }, never, never, true, never>;
}
